.. _reverberation-tutorial:

Reverberation and variability-energy spectra (TBC)
--------------------------------------------------

.. Note ::

    For a general introduction to HENDRICS's workflow, please read the
    :ref:`quicklook-tutorial` tutorial


TBD
